function binomcdf( m, n, p, ier )

!-----------------------------------------------------------------------
!
!     Computes the probability that a random variable distributed
!     according to the binomial distribution with sample size N and
!     parameter P, is less than or equal to M.
!
!     M     - Input . Value of the variable (M >= 0 )         - Integer
!     N     - Input . Sample size (N > 0)                     - Integer
!     P     - Input . parameter of the binomial (0 <= P <= 1) - Real
!     IER   - Output. Return code :                           - Integer
!                     0 = normal
!                     1 = invalid input argument
!                     3 = result out of limits in BETACDF
!
!     External functions called:
!       BETACDF (and DLGAMA if not in Fortran library)
!
!     Fortran functions called:
!       NONE
!
!-----------------------------------------------------------------------

   implicit none

   !  Function
   !  --------

   real(kind=8) :: binomcdf

   !  Arguments
   !  ---------

   real(kind=8), intent(in) :: p
   integer, intent(in) :: m, n
   integer, intent(out) :: ier

   !  Local declarations
   !  ------------------

   real(kind=8), external :: betacdf

   real(kind=8), parameter :: zero=0.0_8, one=1.0_8
   real(kind=8) :: t

   !--------------------------------------------------------------------

   binomcdf = zero
   ier = 0

   !  Test for valid input arguments

   if ( n <= 0 .or. m < 0 .or. m > n .or. p < zero .or. p > one ) then
      ier = 1
      binomcdf = -one
      return
   end if

   !  Special cases

   if ( m == n ) then
      binomcdf = one
      return
   end if
   if ( p == one ) return
   if ( p == zero ) then
      binomcdf = one
      return
   end if

   !  General case

   t = n - m
   binomcdf = one - betacdf( p, m+one, t, ier )

end function binomcdf
