function fcdf( x, p, q, ier )

!-----------------------------------------------------------------------
!
!     Computes the probability that a random variable distributed
!     according to the Fisher-Snedecor distribution with P and Q degrees
!     of freedom, is less than or equal to X.
!
!     X     - Input . Value of the variable          (X >= 0) - Real
!     P     - Input . First degrees of freedom       (P >  0) - Real
!     Q     - Input . Second   "    "     "          (Q >  0) - Real
!     IER   - Output. Return code :                           - Integer
!                     0 = normal
!                     1 = invalid input argument
!                         (then fcdf = -1.)
!                     2 = maximum number of iterations reached
!                         (then fcdf = value at last iteration,
!                                        or zero)
!                     3 = result out of limits
!                         (fcdf < -eps or fcdf > 1+eps)
!
!     External functions called:
!       BETACDF
!
!     NOTE : the error on FCDF is supposed to be minimal.
!
!-----------------------------------------------------------------------

   implicit none

   !  Function
   !  --------

   real(kind=8) :: fcdf

   !  Arguments
   !  ---------

   real(kind=8), intent(in) :: x, p, q
   integer, intent(out) :: ier

   !  local declarations
   !  ------------------

   real(kind=8), external :: betacdf

   real(kind=8), parameter :: zero=0.0_8, half=0.5_8, one=1.0_8

   !-----------------------------------------------------------------

   !  Test for valid input arguments

   if ( x < zero .or. p <= zero .or. q <= zero ) then
      ier  = 1
      fcdf = -one
      return
   end if

   fcdf = betacdf( p*x/(p*x+q), p*half, q*half, ier )

end function fcdf
