subroutine ndtri1( p, x, ier )

!-----------------------------------------------------------------------
!
!     Computes X = p**(-1)(P), the argument X such that P = p(X) =
!     the probability that the random variable u, distributed
!     normally(0,1), is less than or equal to X.
!     From IBM-SSP subroutine NDTRI
!
!     P     - Input . Probability                 (0 < P < 1) - Real
!     X     - Output. Value of the variable                   - Real
!     IER   - Output. Return code :                           - Integer
!                     0 = normal
!                     1 = invalid input argument
!                         (then X = 0.)
!
!-----------------------------------------------------------------------

   !  Arguments
   !  ---------

   real, intent(in) :: p
   real, intent(out) :: x
   integer, intent(out) :: ier

   !  local declarations
   !  ------------------

   real(kind=8), parameter :: zero=0.0, half=0.5, one=1.0
   real :: c, t, t2

   !-----------------------------------------------------------------

   !  Test for valid input arguments

   if ( p <= zero .or. p >= one ) then
      ier = 1
      x = zero
      return
   end if

   ier = 0

   c  = p
   if ( c > half ) c = one - c
   t2 = log( one/(c*c) )
   t  = sqrt(t2)
   x  = t - (2.515517e0+0.802853e0*t+0.010328e0*t2)/               &
               (1.0e0+1.432788e0*t+0.189269e0*t2+0.001308e0*t*t2)
   if ( p < half ) x = -x

end subroutine ndtri1
