subroutine basfun( kodf, fun, err, maxit, a1, a2, a3, a4, a5, a6 )

   ! dll pour "Fonctions de base"

   ! entree:
   !    kodf : code fonction (entier)
   !           si kodf>0 calcul de la fonction de repartition
   !           si kodf<0 calcul de la constante servant dans les moments
   !    maxit: nbre max. iterations (entier)
   !    a1 : argument  (reel*8)
   !    a2 : argument  (reel*8)
   !    a3 : argument  (reel*8)
   !    a4 : argument  (reel*8)
   !    a5 : argument  (reel*8)
   !    a6 : argument  (reel*8)
   ! sortie:
   !    fun : resultat  (reel*8)
   !    err :  0 = OK   (entier)
   !          /0 = erreur dans fonction
   !          99 = kodf errone

   implicit none

   DLL_EXPORT basfun

   real(kind=8), intent(in) :: a1, a2, a3, a4, a5, a6
   integer, intent(in) :: kodf, maxit
   real(kind=8), intent(out) :: fun
   integer, intent(out) :: err

   ! cdf's:
   real(kind=8), external :: betacdf
   real(kind=8), external :: betanccdf
   real(kind=8), external :: chi2cdf
   real(kind=8), external :: chi2nccdf
   real(kind=8), external :: fdnccdf
   real(kind=8), external :: k2cdf
   real(kind=8), external :: kprimecdf
   real(kind=8), external :: ksi2cdf
   real(kind=8), external :: lambda2cdf
   real(kind=8), external :: lprimecdf
   real(kind=8), external :: ncdf
   real(kind=8), external :: phi2cdf
   real(kind=8), external :: poissoncdf
   real(kind=8), external :: psi2cdf
   real(kind=8), external :: tdnccdf
   real(kind=8), external :: tnccdf
   real(kind=8), external :: tcdf
   ! inverses:
   real(kind=8), external :: norminv
   ! pdf's:

!! real(kind=8) :: dlgama
   real(kind=8), parameter :: zero=0.0_8, half=0.5_8, two=2.0_8
   real(kind=8), parameter :: explower=-706.893_8
   real(kind=8) :: x, y
   integer :: iflag

   !--------------------------------------------------------------------

   fun = zero
   err = 0

   if ( kodf > 0 ) then   ! Fonction de repartition (ou inverse)

      select case (kodf)

         case (1)                     ! beta cdf
            fun = betacdf( a1, a2, a3, err )

         case (2)                     ! noncentral beta cdf
            fun = betanccdf( a1, a2, a3, a4, a5, maxit, err )

         case (3)                     ! chi-square cdf
            fun = chi2cdf( a1, a2, a3, err )

         case (4)                     ! k-square cdf
            fun = k2cdf( a1, a2, a3, a4, a5, a6, maxit, err )

         case (5)                     ! k-prime cdf
            fun = kprimecdf( a1, a2, a3, a4, a5, maxit, err )

         case (6)                     ! ksi-square cdf
            fun = ksi2cdf( a1, a2, a3, a4, a5, maxit, iflag, err )

         case (7)                     ! lambda-square cdf
            fun = lambda2cdf( a1, a2, a3, a4, a5, maxit, err )

         case (8)                     ! lambda-prime cdf
            fun = lprimecdf( a1, a2, a3, a4, maxit, err )

         case (9)                     ! normal cdf
            fun = ncdf( a1 )

         case (10)                    ! phi-square cdf
            fun = phi2cdf( a1, a2, a3, a4, maxit, err )

         case (11)                    ! poisson cdf
            fun = poissoncdf( nint(a1), a2, err )

         case (12)                    ! psi-square cdf
            fun = psi2cdf( a1, a2, a3, a4, a5, maxit, iflag, err )

         case (13)                    ! inverse of normal cdf
            fun = norminv( a1 )

         case (14)                    ! noncentral chi-square cdf
            fun = chi2nccdf( a1, a2, a3, a4, maxit, err )

         case (15)                    ! doubly noncentral F cdf
            fun = fdnccdf( a1, a2, a3, a4, a5, a6, err )

         case (16)                    ! doubly noncentral t cdf
            fun = tdnccdf( a1, a2, a3, a4, a5, err )

         case (17)                    ! noncentral t cdf
            fun = tnccdf( a1, a2, a3, a4, maxit, err )

         case (18)                    ! Student t cdf
            fun = tcdf( a1, a2, a3, err )

         case default                 ! error
            err = 99
      end select

   else                   ! Constante servant dans le calcul des moments

      select case (-kodf)

         case (5)                     ! k-prime cdf
            x = dlgama(a2*half+half)+dlgama(a3*half-half)-dlgama(a2*half)-dlgama(a3*half)
            if ( x >= explower .and. a2 > zero ) fun = exp(x)*sqrt(a3/a2)

         case (8)                     ! lambda-prime cdf
            x = dlgama(a2*half+half)-dlgama(a2*half)
            if ( x >= explower .and. a2 > zero ) fun = exp(x)*sqrt(two/a2)

         case (17)                    ! noncentral t cdf
            x = dlgama(a2*half-half)-dlgama(a2*half)
            if ( x >= explower ) fun = exp(x)*sqrt(a2*half)

         case default                 ! error
            err = 99
      end select

   end if

end subroutine basfun
   include "\jac\distri90\betacdf.f90"
   include "\jac\distri90\betanccdf.f90"
   include "\jac\distri90\chi2cdf.f90"
   include "\jac\distri90\chi2nccdf.f90"
   include "\jac\distri90\fdnccdf.f90"
   include "\jac\distri90\k2cdf.f90"
   include "\jac\distri90\kprimecdf.f90"
   include "\jac\distri90\ksi2cdf.f90"
   include "\jac\distri90\lambda2cdf.f90"
   include "\jac\distri90\lprimecdf.f90"
   include "\jac\distri90\ncdf.f90"
   include "\jac\distri90\phi2cdf.f90"
   include "\jac\distri90\poissoncdf.f90"
   include "\jac\distri90\psi2cdf.f90"
   include "\jac\distri90\norminv.f90"
   include "\jac\distri90\tcdf.f90"
   include "\jac\distri90\tnccdf.f90"
   include "\jac\distri90\tdnccdf.f90"
