function binomcfcdf( x, a, b, u, ier )

!-----------------------------------------------------------------------
!
!     Computes the probability that a random variable distributed
!     according to the fiducial continued binomial distribution with
!     parameters A, B, U, is less than or equal to X.
!     The function is defined on the interval (-1; N).
!
!     X     - Input . Value of the variable (0 <= X <= 1)     - Real
!     A     - Input . parameter: number of "positive" events  - Real
!                     (A > 0)
!     B     - Input . parameter: number of "negative" events  - Real
!                     (B > 0)
!     U     - Input . parameter                               - Real
!                     (0 <= U <= 1)
!     IER   - Output. Return code :                           - Integer
!                     0 = normal
!                     1 = invalid input argument
!                     2 = error in auxiliary function
!
!     External functions called:
!       BINOMCDF
!
!     Fortran functions called:
!       NINT
!
!-----------------------------------------------------------------------

   implicit none

   !  Function
   !  --------

   real(kind=8) :: binomcfcdf

   !  Arguments
   !  ---------

   real(kind=8), intent(in) :: x, a, b, u
   integer, intent(out) :: ier

   !  Local declarations
   !  ------------------

   real(kind=8), external :: binomccdf

   real(kind=8), parameter :: zero=0.0_8, one=1.0_8
   real(kind=8), parameter :: prec=1.0e-14_8
   real(kind=8) :: t
   integer :: m

   !--------------------------------------------------------------------

   !  Test for valid input arguments

   if ( a < zero .or. b < zero .or. u < zero .or.   &
        x < zero .or. x > one ) then
      ier = 1
      binomcfcdf = -one
      return
   end if

   binomcfcdf = zero
   ier = 0

   !  Special cases

   if ( x < prec .and. a == zero ) then
      return
   else if ( x > one-prec .and. b == zero ) then
      binomcfcdf = one
      return
   end if

   !  General case

   binomcfcdf = one - binomccdf( a-u, nint(a+b), x, ier )
   if ( ier /= 0 ) ier = 2

end function binomcfcdf
