function poissonccdf( x, p, ier )

!-----------------------------------------------------------------------
!
!     Computes the probability that a random variable distributed
!     according to the continuous poisson distribution with parameter P,
!     is less than or equal to X.
!
!     X     - Input . Value of the variable         (X >=-1)  - Real
!     P     - Input . Parameter                     (P >= 0)  - Real
!     IER   - Output. Return code :                           - Integer
!                     0 = normal
!                     1 = invalid input argument
!                         (then POISSONCCDF = 0.)
!
!     External functions called:
!       POISSONCDF  POISSONPMF
!
!     Fortran functions called:
!       INT
!
!-----------------------------------------------------------------------

   implicit none

   !  Function
   !  --------

   real(kind=8) :: poissonccdf

   !  Arguments
   !  ---------

   real(kind=8), intent(in) :: p
   integer, intent(in) :: x
   integer, intent(out) :: ier

   !  Local declarations
   !  ------------------

   real(kind=8), external :: poissoncdf, poissonpmf

   real(kind=8), parameter :: zero=0.0_8, one=1.0_8

   real(kind=8) :: a, b
   integer :: y

   !--------------------------------------------------------------------

   poissonccdf = zero
   if ( x < -one .or. p < zero ) then  ! Test for valid input arguments
      ier = 1
      return
   end if

   ier = 0
   y = int(x)
   a = poissoncdf( y, p, ier )
   if ( ier /= 0 ) return
   b = poissonpmf( y+1, p, ier )
   if ( ier /= 0 ) return
   poissonccdf = a + (x-y)*b

end function poissonccdf
