function poissoncdf( x, p, ier )

!-----------------------------------------------------------------------
!
!     Computes the probability that a random variable distributed
!     according to the poisson distribution with parameter P, is
!     less than or equal to X.
!
!     X     - Input . Value of the variable         (X >= 0)  - Integer
!     P     - Input . Parameter                     (P >= 0)  - Real
!     IER   - Output. Return code :                           - Integer
!                     0 = normal
!                     1 = invalid input argument
!                         (then POISSONCDF = 0.)
!
!     External functions called:
!       CHI2CDF
!
!     Fortran functions called:
!       EXP  REAL
!
!-----------------------------------------------------------------------

   implicit none

   !  Function
   !  --------

   real(kind=8) :: poissoncdf

   !  Arguments
   !  ---------

   real(kind=8), intent(in) :: p
   integer, intent(in) :: x
   integer, intent(out) :: ier

   !  Local declarations
   !  ------------------

   real(kind=8), external :: chi2cdf

   real(kind=8), parameter :: zero=0.0_8, one=1.0_8
   real(kind=8), parameter :: dflimit=1.0e6_8

   real(kind=8) :: y

   !--------------------------------------------------------------------

   if ( x < 0 .or. p < zero ) then  ! Test for valid input arguments
      ier = 1
      poissoncdf = zero
      return
   end if

   ier = 0
   if ( p <= zero ) then
      poissoncdf = one
   else
      if ( x == 0 ) then
         poissoncdf = exp( -p )
      else
         y = real(x+x+2,kind=8)
         poissoncdf = one - chi2cdf( p+p, y, dflimit, ier )
      end if
   end if

end function poissoncdf
