function poissoncfcdf( x, a, u, ier )

!-----------------------------------------------------------------------
!
!     Computes the probability that a random variable distributed
!     according to the fiducial continued poisson distribution with
!     parameters A, U is less than or equal to X.
!
!     X     - Input . Value of the variable         (X >= 0)  - Real
!     A     - Input . parameter: number of "positive" events  - Real
!                     (A > 0)
!     U     - Input . parameter                               - Real
!                     (0 <= U <= 1)
!     IER   - Output. Return code :                           - Integer
!                     0 = normal
!                     1 = invalid input argument
!                         (then POISSONCFCDF = 0.)
!
!     External functions called:
!       POISSONCCDF
!
!     Fortran functions called:
!       INT
!
!-----------------------------------------------------------------------

   implicit none

   !  Function
   !  --------

   real(kind=8) :: poissoncfcdf

   !  Arguments
   !  ---------

   real(kind=8), intent(in) :: x, a, u
   integer, intent(out) :: ier

   !  Local declarations
   !  ------------------

   real(kind=8), external :: poissonccdf

   real(kind=8), parameter :: zero=0.0_8, one=1.0_8

   !--------------------------------------------------------------------

   poissoncfcdf = zero
   ! Test for valid input arguments
   if ( a < zero .or. u < zero .or. x < zero ) then
      ier = 1
      return
   end if

   ier = 0
   poissoncfcdf = one - poissonccdf( a-u, x, ier )

end function poissoncfcdf
