subroutine normratio( w, xm, ym, xs, ys, r, f, ier )

   ! dll pour densite du rapport de 2 normales
   ! BL 2010

   ! entree:
   !    w : rapport x/y (reel*8)
   !    xm: moyenne     (reel*8)
   !    ym: moyenne     (reel*8)
   !    xs: ec.type     (reel*8)
   !    ys: ec.type     (reel*8)
   !    r : correlation (reel*8)
   ! sortie:
   !    f   : resultat  (reel*8)
   !    ier :  0 = OK   (entier)
   !          /0 = erreur dans fonction

   implicit none

   DLL_EXPORT normratio

   real(kind=8), intent(in) :: w, xm, ym, xs, ys, r
   real(kind=8), intent(out) :: f
   integer, intent(out) :: ier

!! real(kind=8), external :: dlgama

   real(kind=8), parameter :: zero=0.0_8, half=0.5_8, one=1.0_8, two=2.0_8
   real(kind=8), parameter :: pi=3.1415926535897932384626434_8
   real(kind=8), parameter :: explower=-706.893_8
   !     explower = minimum valid argument for the exponential function
   integer, parameter :: maxit=5000   ! maximum number of iterations

   real(kind=8) :: a, hb, hf, fp, r2r, u, v, ww, xms, yms
   integer :: j, j0

   !--------------------------------------------------------------------

   f = zero
   ier = 0
   !  Test for valid input arguments
   if ( r <= -one .or. r >= one .or. xs <= zero .or. ys <= zero ) then
      ier = 1
      return
   end if

   ww = w*ys/xs
   xms = xm/xs
   yms = ym/ys
   r2r = one - r*r
   u = yms + xms*ww - r*(xms+yms*ww)
   v = one + ww*ww - two*r*ww
   a = half*u*u/v/r2r
   j0 = max(0, int(a-half))
   if ( j0 < 50 ) j0 = 0
   hf = j0*log(a) - dlgama(j0+half) - half*(xms*xms+yms*yms-two*r*xms*yms)/r2r &
        + half*log(r2r/pi) - log(v)
   if ( hf >= explower ) then
      if ( hf <= -explower ) then
         hf = exp(hf)
      else
         ier = 2
         return
      end if
   else
      return
   end if

   hb = hf
   f = hf
   fp = f
   do j = 1, j0
      hf = hf/(j0+j-half)*a
      hb = hb/a*(j0-j+half)
      f = f + hf + hb
      if ( f == fp ) then
         f = f*ys/xs
         return
      end if
      fp = f
   end do
   do j = j0+1, maxit
      hf = hf/(j-half)*a
      f = f + hf
      if ( f == fp ) then
         f = f*ys/xs
         return
      end if
      fp = f
   end do
   if ( j >= maxit ) ier = 3
   f = f*ys/xs

end subroutine normratio
