function poissonpmf( m, p, ier )

!-----------------------------------------------------------------------
!
!     Computes the probability that a random variable distributed
!     according to the poisson distribution with parameter P,
!     is equal to M (probability mass function).
!
!     M     - Input . Value of the variable (M >= 0 )         - Integer
!     P     - Input . parameter of the poisson (P >= 0)       - Real
!     IER   - Output. Return code :                           - Integer
!                     0 = normal
!                     1 = invalid input argument
!
!     External functions called:
!       (DLGAMA if not in Fortran library)
!
!     Fortran functions called:
!       DLGAMA  LOG
!
!-----------------------------------------------------------------------

   implicit none

   !  Function
   !  --------

   real(kind=8) :: poissonpmf

   !  Arguments
   !  ---------

   real(kind=8), intent(in) :: p
   integer, intent(in) :: m
   integer, intent(out) :: ier

   !  Local declarations
   !  ------------------

!! real(kind=8), external :: dlgama

   real(kind=8), parameter :: zero=0.0_8, one=1.0_8
   real(kind=8), parameter :: explower=-706.893_8
   !     explower = minimum valid argument for the exponential function

   real(kind=8) :: t

   !--------------------------------------------------------------------

   poissonpmf = zero
   ier = 0

   !  Test for valid input arguments

   if ( m < 0 .or. p < zero ) then
      ier = 1
      return
   end if

   if ( p == zero ) then
      if ( m == 0 ) poissonpmf = one
   else if ( m == 0 ) then
      poissonpmf = exp( -p )
   else
      t = m*log(p) - dlgama(m+one) - p
      if ( t > explower ) poissonpmf = exp(t)
   end if

end function poissonpmf
