function harmong( a, n )

!-----------------------------------------------------------------------
!
!     Computes generalized harmonic number
!
!     A     - INPUT . Power parameter                         - Real
!     N     - INPUT . Argument                        (N > 0) - Integer
!
!-----------------------------------------------------------------------

   implicit none

   !     Function
   !     --------

   real(kind=8) :: harmong

   !     Arguments
   !     ---------

   real(kind=8), intent(in) :: a
   integer, intent(in) :: n

   !     Local declarations
   !     ------------------

   real(kind=8), parameter :: zero=0.0_8, one=1.0_8, alim=5.0_8
   real(kind=8), save :: a0, h0=one
   real(kind=8) :: aa, h, h1
   integer, save :: n0=1
   integer :: i

   !--------------------------------------------------------------------

   if ( n < 1 ) then
      harmong = -one
      return
   endif
   if ( a /= a0 ) then
      n0 = 1
      h0 = one
   endif
   h = h0
   if ( a == zero ) then
      h = n
   else if ( a > zero ) then
      if ( a == one ) then
         if ( n >= n0 ) then
            do i = n0+1, n
               h = h + one/i
            end do
         else
            do i = n+1, n0
               h = h - one/i
            end do
         end if
      else if ( a < alim ) then
         if ( n >= n0 ) then
            do i = n0+1, n
               h = h + one/(i**a)
            end do
         else
            do i = n+1, n0
               h = h - one/(i**a)
            end do
         end if
      else
         if ( n >= n0 ) then
            h1 = h
            do i = n0+1, n
               h = h + one/(i**a)
               if ( h == h1 ) exit
               h1 = h
            end do
         else
            do i = n+1, n0
               h = h - one/(i**a)
            end do
         end if
      end if
   else
      if ( a == -one ) then
         h = n*(n+1)/2
      else
         aa = -a
         if ( n >= n0 ) then
            do i = n0+1, n
               h = h + i**aa
            end do
         else
            do i = n+1, n0
               h = h - i**aa
            end do
         end if
      end if
   end if
   n0 = n
   h0 = h
   a0 = a
   harmong = h

end function harmong
