function hypg191( x, a, b, c, ier )

!-----------------------------------------------------------------------
!
!     Computes the Gauss hypergeometric function 2F1.
!
!     X     - Input . Value of the variable (|X| <= 1)        - Real
!                     (|X| < 1 if c < a+b)
!     A     - Input . 1st (numerator) parameter               - Real
!     B     - Input . 2nd (numerator) parameter               - Real
!     C     - Input . 3rd (denominator) parameter             - Real
!                     (C /= 0,-1,-2,...)
!     IER   - Output. Return code :                           - Integer
!                     0 = normal
!                     1 = invalid input argument
!                         (then hypg191 = 0)
!                     2 = maximum number of iterations reached
!                         (then hypg191 = value at last iteration)
!
!     Fortran functions called:
!       ABS  NINT
!
!     From Relph A. P. (1963). Algorithm 191 Hypergeometric.
!          Communications of the ACM, 6, 388.
!
!-----------------------------------------------------------------------

   implicit none

   !  Function
   !  --------

   real(kind=8) :: hypg191

   !  Arguments
   !  ---------

   real(kind=8), intent(in) :: x, a, b, c
   integer, intent(out) :: ier

   !  Local declarations
   !  ------------------

   real(kind=8), parameter :: zero=0.0_8, one=1.0_8
   real(kind=8) :: aa, bb, cc, d, s, t, y, xx
!! real(kind=16) :: aa, bb, cc, d, s, t, y, xx
   integer :: i

   !--------------------------------------------------------------------

   ier = 0

   if ( c == zero .or. c == -abs(nint(c)) .or. abs(x) > one .or.  &
        one-x <  1.0e-15_8 .and. c-a-b <= zero ) then
      hypg191 = zero
      ier = 1                ! Invalid parameter
      return
   else if ( x == zero ) then
      hypg191 = one
      return
   end if

   aa = a
   bb = b
   cc = c
   xx = x
   s = one
   y = one
!! s = 1.0_16
!! y = 1.0_16
   do i = 0, 5000
      d = (i+1)*((i+cc)**2)
      y = y * ((i+aa)/d)*(i+bb)*(i+cc)*xx
      t = s + y
      if ( s == t ) then
         hypg191 = s
         return
      end if
      s = t
   end do
   hypg191 = s
   ier = 2

end function hypg191
