function gamdvi( ia, idum, ier )

!-----------------------------------------------------------------------
!
!     Returns a random variable distributed according to a Gamma
!     distribution with integer parameter ia.
!     This is the real*8 version of the Gamdev function
!     from Numerical Recipes in Fortran by Press et al. (1992).
!
!     ia    - Input . Parameter of the Gamma distribution     - Integer
!                     (ia >= 1)
!     idum  - Input . A negative integer to initialize the    - Integer
!             Output. random sequence. Thereafter do not
!                     alter this argument between successive
!                     deviates in a sequence
!     ier   - Output. Return code :                           - Integer
!                     0 = normal
!                     1 = invalid input argument alpha
!                         (then gamdvi = -1.0)
!
!     External functions called:
!        RAN12
!     Fortran  functions called:
!        EXP  LOG  SQRT
!
!-----------------------------------------------------------------------

   implicit none

   !  Function
   !  --------

   real(kind=8) :: gamdvi

   !  Arguments
   !  ---------

   integer, intent(in) :: ia
   integer, intent(inout) :: idum
   integer, intent(out) :: ier

   !  Local declarations
   !  ------------------

   real(kind=8), external :: ran12

   real(kind=8), parameter :: zero=0.0_8, one=1.0_8, two=2.0_8
   real(kind=8) :: am, e, s, v1, v2, x, y
   integer :: j

   !--------------------------------------------------------------------

   ier = 0
   if ( ia < 1 ) then
      ier = 1
      gamdvi = -one
      return
   end if
   if ( ia < 6 ) then
      x = one
      do j = 1, ia
        x = x*ran12(idum)
      end do
      x = -log(x)
   else
      do
         v1 = two*ran12(idum)-one
         v2 = two*ran12(idum)-one
         if ( v1**2+v2**2 > one ) cycle
         y = v2/v1
         am = ia-1
         s = sqrt(two*am+one)
         x = s*y+am
         if ( x <= zero ) cycle
         e = (one+y**2)*exp(am*log(x/am)-s*y)
         if ( ran12(idum) <= e ) exit
      end do
   end if
   gamdvi = x

end function gamdvi
