function ran1( idum )

!     "Minimal" random number generator of Park and Miller with
!     Bays-Durham shuffle and added safeguards.
!     Returns a uniform random deviate between 0.0 and 1.0 (exclusive
!     of the endpoint values). Call with idum a negative integer to
!     initialize; thereafter, do not alter idum between successive
!     deviates in a sequence. RNMX should approximate the largest
!     floating value that is less than 1.

   implicit none

   !  Function
   !  --------

   real :: ran1

   !  Arguments
   !  ---------

   integer, intent(inout) :: idum

   !  Local declarations
   !  ------------------

   integer, parameter :: ia=16807, im=2147483647, iq=127773, ir=2836
   integer, parameter :: ntab=32, ndiv=1+(im-1)/ntab
   real, parameter :: am=1.0/im
   real, parameter :: eps=0.12e-6, rnmx=1.0-eps

   integer :: j, k
   integer, save :: iy=0
   integer, dimension(ntab), save :: iv=(/ (0,j=1,ntab) /)

   if ( idum <= 0 .or. iy == 0 ) then
     idum = max(-idum,1)
     do j = ntab+8, 1, -1
       k = idum/iq
       idum = ia*(idum-k*iq)-ir*k
       if ( idum < 0 ) idum = idum+im
       if ( j <= ntab ) iv(j) = idum
     end do
     iy = iv(1)
   end if
   k = idum/iq
   idum = ia*(idum-k*iq)-ir*k
   if ( idum < 0 ) idum = idum+im
   j = 1 + iy/ndiv
   iy = iv(j)
   iv(j) = idum
   ran1 = min(am*iy,rnmx)

end function ran1
