subroutine binormdev( idum, rho, x1, x2 )

!-----------------------------------------------------------------------
!
!     Returns a random vector distributed according to a binormal
!     distribution with zero means, unit variances and rho correlation.
!
!     idum  - Input . A negative integer to initialize the    - Integer
!             Output. random sequence. Thereafter do not
!                     alter this argument between successive
!                     deviates in a sequence
!     rho   - Input . Correlation              (-1<= rho <=1) - Real
!     x1    - Output. First coordinate                        - Real
!     x2    - Output. Second coordinate                       - Real
!
!     External functions called:
!        GAUSSBM
!     Fortran  functions called:
!        SQRT
!
!-----------------------------------------------------------------------

   implicit none

   !  Arguments
   !  ---------

   real(kind=8), intent(in) :: rho
   integer, intent(inout) :: idum
   real(kind=8), intent(out) :: x1, x2

   !  Local declarations
   !  ------------------

   real(kind=8), external :: gaussbm

   real(kind=8), parameter :: one=1.0_8

   !--------------------------------------------------------------------

   x1 = gaussbm(idum)
   x2 = rho*x1 + sqrt(one-rho*rho)*gaussbm(idum)

end subroutine binormdev
