function gaussbm( idum )

!-----------------------------------------------------------------------
!
!     Returns a random variable distributed according to a Normal
!     distribution using Box & Muller (1958) method.
!
!     idum  - Input . A negative integer to initialize the    - Integer
!             Output. random sequence. Thereafter do not
!                     alter this argument between successive
!                     deviates in a sequence
!
!     External functions called:
!        RAN12
!     Fortran  functions called:
!        COS  LOG  SIN  SQRT
!
!-----------------------------------------------------------------------

   implicit none

   !  Function
   !  --------

   real(kind=8) :: gaussbm

   !  Arguments
   !  ---------

   integer, intent(inout) :: idum

   !  Local declarations
   !  ------------------

   real(kind=8), external :: ran12

   real(kind=8), parameter :: twopi=6.2831853071795865_8
   real(kind=8), save :: gset
   real(kind=8) :: fac, v
   logical, save :: iset=.true.

   !--------------------------------------------------------------------

   if ( iset ) then
      fac = sqrt(-2.0_8*log(ran12(idum)))
      v = twopi*ran12(idum)
      gset = fac*sin(v)
      gaussbm = fac*cos(v)
      iset = .false.
   else
      gaussbm = gset
      iset = .true.
   end if

end function gaussbm
