function gausstrunc( xlow, xupp, idum )

!-----------------------------------------------------------------------
!
!     Returns a random variable distributed according to a truncated
!     Normal distribution.
!
!     XLOW  - Input . Lower limit of the variable             - Real
!     XUPP  - Input . Upper limit of the variable             - Real
!     IDUM  - Input . A negative integer to initialize the    - Integer
!             Output. random sequence. Thereafter do not
!                     alter this argument between successive
!                     deviates in a sequence
!
!     External functions called:
!        RAN12
!     Fortran  functions called:
!        LOG
!
!-----------------------------------------------------------------------

   implicit none

   !  Function
   !  --------

   real(kind=8) :: gausstrunc

   !  Arguments
   !  ---------

   real(kind=8), intent(in) :: xlow, xupp
   integer, intent(inout) :: idum

   !  Local declarations
   !  ------------------

   real(kind=8), external :: ran12

   real(kind=8), parameter :: zero=0.0_8, two=2.0_8
   real(kind=8) :: e, y, z

   !--------------------------------------------------------------------

   if ( xlow <= zero .and . xupp >= zero ) then
      z = zero
   else if ( xlow > zero ) then
      z = -xlow*xlow
   else
      z = -xupp*xupp
   end if
   e = xupp - xlow
   do
      y = xlow + e*ran12(idum)
      if ( two*log(ran12(idum)) <= -y*y-z ) exit
   end do
   gausstrunc = y

end function gausstrunc
