function tinv( prob, p, plim, ier )

!-----------------------------------------------------------------------
!
!     Computes the value of a random variable distributed
!     according to the Student's t distribution with P degrees of
!     freedom, given the cdf at this value.
!
!     PROB  - Input . The probability (cdf)                   - Real
!     P     - Input . Degrees of freedom              (P > 0) - Real
!     PLIM  - Input . Limit for P over which the distribution - Real
!                     is approximated by a normal distr.
!     IER   - Output. Return code :                           - Integer
!                     0 = normal
!                     1 = invalid input argument
!                         (then tinv = 0.)
!                     2 = error in auxiliary function
!
!     External functions called:
!       IBETA  NORMINV
!
!-----------------------------------------------------------------------

   implicit none

   !  Function
   !  --------

   real(kind=8) :: tinv

   !  Arguments
   !  ---------

   real(kind=8), intent(in) :: prob, p, plim
   integer, intent(out) :: ier

   !  local declarations
   !  ------------------

   real(kind=8), external :: ibeta, norminv

   real(kind=8), parameter :: zero=0.0_8, half=0.5_8, one=1.0_8

   real(kind=8) :: b, pb

   !-----------------------------------------------------------------

   !  Test for valid input arguments

   tinv = zero
   if ( p <= zero ) then
      ier  = 1
      return
   end if

   ier = 0
   if ( p <= plim ) then
      pb = abs(prob+prob-one)
      b  = ibeta( pb, half, p*half, ier )
      if ( ier /= 0 ) then
         ier = 2
         return
      end if
      tinv = sqrt(b*p/(one-b))
      if ( prob < half ) tinv = -tinv
   else
      tinv = norminv( prob )
   end if

end function tinv
